@@ -49,7 +49,7 @@ void CoreStartData::Save(DataWriter &out) const
 	out.Write("start", identifier);
 	out.BeginChild();
 	{
-		out.Write("system", system->Name());
+		out.Write("system", system->TrueName());
 		out.Write("planet", planet->TrueName());
 		if(date)
 			out.Write("date", date.Day(), date.Month(), date.Year());
@@ -69,18 +69,18 @@ Date CoreStartData::GetDate() const
 
 const Planet &CoreStartData::GetPlanet() const
 {
-	return planet ? *planet : *GameData::Planets().Get("New Boston");
+	return (planet && planet->IsValid()) ? *planet : *GameData::Planets().Get("New Boston");
 }
 
 
 
 const System &CoreStartData::GetSystem() const
 {
-	if(system)
+	if(system && system->IsValid())
 		return *system;
 	const System *planetSystem = GetPlanet().GetSystem();
 
-	return planetSystem ? *planetSystem : *GameData::Systems().Get("Rutilicus");
+	return (planetSystem && planetSystem->IsValid()) ? *planetSystem : *GameData::Systems().Get("Rutilicus");
 }
 
 
