@@ -15,7 +15,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 
 #pragma once
 
-#include "Sale.h"
+#include "Shop.h"
 
 class DataNode;
 class Outfit;
@@ -36,5 +36,5 @@ private:
 	// The number of different items this object can assign to ships.
 	int cargo = 3;
 	std::vector<std::string> commodities;
-	std::set<const Sale<Outfit> *> outfitters;
+	std::set<const Shop<Outfit> *> outfitters;
 };
