@@ -71,7 +71,6 @@ using namespace std;
 namespace {
 	const std::string SHOW_ESCORT_SYSTEMS = "Show escort systems on map";
 	const std::string SHOW_STORED_OUTFITS = "Show stored outfits on map";
-	const unsigned MAX_MISSION_POINTERS_DRAWN = 12;
 	const double MISSION_POINTERS_ANGLE_DELTA = 30.;
 	const int MAX_STARS = 5;
 
@@ -92,12 +91,13 @@ namespace {
 		unsigned unavailable = 0;
 
 	private:
-		unsigned maximumActive = MAX_MISSION_POINTERS_DRAWN;
+		unsigned maximumActive = MapPanel::MAX_MISSION_POINTERS_DRAWN;
 	};
 
 	void PointerDrawCount::Reserve()
 	{
-		maximumActive = max(MAX_MISSION_POINTERS_DRAWN / 2, MAX_MISSION_POINTERS_DRAWN - (available + unavailable));
+		maximumActive = max(MapPanel::MAX_MISSION_POINTERS_DRAWN / 2,
+			MapPanel::MAX_MISSION_POINTERS_DRAWN - (available + unavailable));
 	}
 
 	unsigned PointerDrawCount::MaximumActive() const
@@ -161,8 +161,6 @@ namespace {
 
 	const Color black(0.f, 1.f);
 
-	// Hovering an escort pip for this many frames activates the tooltip.
-	const int HOVER_TIME = 60;
 	// Length in frames of the recentering animation.
 	const int RECENTER_TIME = 20;
 
@@ -182,19 +180,6 @@ namespace {
 		return false;
 	}
 
-	pair<bool, bool> BlinkMissionIndicator(const PlayerInfo &player, const Mission &mission, int step)
-	{
-		bool blink = false;
-		int daysLeft = 1;
-		if(mission.Deadline())
-		{
-			daysLeft = player.RemainingDeadline(mission);
-			int blinkFactor = min(6, max(1, daysLeft));
-			blink = (step % (10 * blinkFactor) > 5 * blinkFactor);
-		}
-		return pair<bool, bool>(blink, daysLeft > 0);
-	}
-
 	// Return total value of raid fleet (if any) and 60 frames worth of system danger.
 	double DangerFleetTotal(const PlayerInfo &player, const System &system, const bool withRaids)
 	{
@@ -208,6 +193,7 @@ namespace {
 
 }
 
+const unsigned MapPanel::MAX_MISSION_POINTERS_DRAWN = 12;
 const float MapPanel::OUTER = 6.f;
 const float MapPanel::INNER = 3.5f;
 const float MapPanel::LINK_WIDTH = 1.2f;
@@ -216,6 +202,33 @@ const float MapPanel::LINK_OFFSET = 7.f;
 
 
 
+void MapPanel::DrawPointer(Point position, unsigned &systemCount, const Color &color, bool drawBack, bool bigger)
+{
+	if(++systemCount > MAX_MISSION_POINTERS_DRAWN)
+		return;
+	Angle angle = Angle(MISSION_POINTERS_ANGLE_DELTA * systemCount);
+	if(drawBack)
+		PointerShader::Draw(position, angle.Unit(), 14.f + bigger, 19.f + 2 * bigger, -4.f, black);
+	PointerShader::Draw(position, angle.Unit(), 8.f + bigger, 15.f + 2 * bigger, -6.f, color);
+}
+
+
+
+pair<bool, bool> MapPanel::BlinkMissionIndicator(const PlayerInfo &player, const Mission &mission, int step)
+{
+	bool blink = false;
+	int daysLeft = 1;
+	if(mission.Deadline())
+	{
+		daysLeft = player.RemainingDeadline(mission);
+		int blinkFactor = min(6, max(1, daysLeft));
+		blink = (step % (10 * blinkFactor) > 5 * blinkFactor);
+	}
+	return pair<bool, bool>(blink, daysLeft > 0);
+}
+
+
+
 MapPanel::MapPanel(PlayerInfo &player, int commodity, const System *special, bool fromMission)
 	: player(player), distance(player),
 	playerSystem(*player.GetSystem()),
@@ -223,12 +236,15 @@ MapPanel::MapPanel(PlayerInfo &player, int commodity, const System *special, boo
 	specialSystem(special),
 	playerJumpDistance(System::DEFAULT_NEIGHBOR_DISTANCE),
 	commodity(commodity),
+	tooltip(170, Alignment::LEFT, Tooltip::Direction::DOWN_RIGHT, Tooltip::Corner::BOTTOM_RIGHT,
+		GameData::Colors().Get("tooltip background"), GameData::Colors().Get("medium")),
 	fromMission(fromMission)
 {
 	Audio::Pause();
 	UI::PlaySound(UI::UISound::SOFT);
 	SetIsFullScreen(true);
 	SetInterruptible(false);
+	zoom.Set(player.MapZoom(), 0);
 	// Recalculate the fog each time the map is opened, just in case the player
 	// bought a map since the last time they viewed the map.
 	FogShader::Redraw();
@@ -245,11 +261,6 @@ MapPanel::MapPanel(PlayerInfo &player, int commodity, const System *special, boo
 			TallyOutfits(player.PlanetaryStorage(), escortSystems);
 	}
 
-	// Initialize a centered tooltip.
-	hoverText.SetFont(FontSet::Get(14));
-	hoverText.SetWrapWidth(150);
-	hoverText.SetAlignment(Alignment::LEFT);
-
 	// Find out how far the player is able to jump. The range of the system
 	// takes priority over the range of the player's flagship.
 	double systemRange = playerSystem.JumpRange();
@@ -286,6 +297,22 @@ void MapPanel::Step()
 		center += recenterVector * (step * (1. - step) * (6. / RECENTER_TIME));
 		--recentering;
 	}
+
+	// The mouse should be pointing to the same map position before and after zooming.
+	bool needsRecenter = !zoom.IsAnimationDone();
+	Point mouse, anchor;
+	if(needsRecenter)
+	{
+		mouse = UI::GetMouse();
+		anchor = mouse / Zoom() - center;
+	}
+
+	zoom.Step();
+
+	// Now, Zoom() has changed (unless at one of the limits). But, we still want
+	// anchor to be the same, so:
+	if(needsRecenter)
+		center = mouse / Zoom() - anchor;
 }
 
 
@@ -311,14 +338,18 @@ void MapPanel::Draw()
 		RingShader::Draw(Zoom() * (playerSystem.Position() + center),
 			(playerJumpDistance + .5) * Zoom(), (playerJumpDistance - .5) * Zoom(), jumpRangeColor);
 
+	// Draw a circle around the selected system.
 	Color brightColor(.4f, 0.f);
 	RingShader::Draw(Zoom() * (selectedSystem->Position() + center),
 		11.f, 9.f, brightColor);
 
 	// Advance a "blink" timer.
 	++step;
-	// Update the tooltip timer [0-60].
-	hoverCount += hoverSystem ? (hoverCount < HOVER_TIME) : (hoverCount ? -1 : 0);
+	// Update the tooltip timer.
+	if(hoverSystem)
+		tooltip.IncrementCount();
+	else
+		tooltip.DecrementCount();
 
 	DrawWormholes();
 	DrawTravelPlan();
@@ -353,64 +384,51 @@ void MapPanel::FinishDrawing(const string &buttonCondition)
 	mapButtonUi->Draw(info, this);
 
 	// Draw the tooltips.
-
-	if(hoverSystem && hoverCount >= HOVER_TIME)
+	if(hoverSystem && tooltip.ShouldDraw())
 	{
 		// Create the tooltip text.
-		if(tooltip.empty())
+		if(!tooltip.HasText())
 		{
 			MapPanel::SystemTooltipData t = escortSystems.at(hoverSystem);
 
+			string text;
 			if(hoverSystem == &playerSystem)
 			{
 				if(player.Flagship())
 					--t.activeShips;
 				if(t.activeShips || t.parkedShips || !t.outfits.empty())
-					tooltip = "You are here, with:\n";
+					text = "You are here, with:\n";
 				else
-					tooltip = "You are here.";
+					text = "You are here.";
 			}
 			// If you have both active and parked escorts, call the active ones
 			// "active escorts." Otherwise, just call them "escorts."
 			if(t.activeShips && t.parkedShips)
-				tooltip += to_string(t.activeShips) + (t.activeShips == 1 ? " active escort\n" : " active escorts\n");
+				text += to_string(t.activeShips) + (t.activeShips == 1 ? " active escort\n" : " active escorts\n");
 			else if(t.activeShips)
-				tooltip += to_string(t.activeShips) + (t.activeShips == 1 ? " escort" : " escorts");
+				text += to_string(t.activeShips) + (t.activeShips == 1 ? " escort" : " escorts");
 			if(t.parkedShips)
-				tooltip += to_string(t.parkedShips) + (t.parkedShips == 1 ? " parked escort" : " parked escorts");
+				text += to_string(t.parkedShips) + (t.parkedShips == 1 ? " parked escort" : " parked escorts");
 			if(!t.outfits.empty())
 			{
 				if(t.activeShips || t.parkedShips)
-					tooltip += "\n";
+					text += "\n";
 
 				unsigned sum = 0;
 				for(const auto &it : t.outfits)
 					sum += it.second;
 
-				tooltip += to_string(sum) + (sum == 1 ? " stored outfit" : " stored outfits");
+				text += to_string(sum) + (sum == 1 ? " stored outfit" : " stored outfits");
 
 				if(HasMultipleLandablePlanets(*hoverSystem) || t.outfits.size() > 1)
 					for(const auto &it : t.outfits)
-						tooltip += "\n - " + to_string(it.second) + " on " + it.first->DisplayName();
+						text += "\n - " + to_string(it.second) + " on " + it.first->DisplayName();
 			}
 
-			hoverText.Wrap(tooltip);
-		}
-		if(!tooltip.empty())
-		{
-			// Add 10px margin to all sides of the text.
-			Point size(hoverText.WrapWidth(), hoverText.Height() - hoverText.ParagraphBreak());
-			size += Point(20., 20.);
-			Point topLeft = (hoverSystem->Position() + center) * Zoom();
-			// Do not overflow the screen dimensions.
-			if(topLeft.X() + size.X() > Screen::Right())
-				topLeft.X() -= size.X();
-			if(topLeft.Y() + size.Y() > Screen::Bottom())
-				topLeft.Y() -= size.Y();
-			// Draw the background fill and the tooltip text.
-			FillShader::Fill(topLeft + .5 * size, size, *GameData::Colors().Get("tooltip background"));
-			hoverText.Draw(topLeft + Point(10., 10.), *GameData::Colors().Get("medium"));
+			tooltip.SetText(text);
 		}
+		tooltip.SetZone((hoverSystem->Position() + center) * Zoom(), Point(20., 20.));
+		tooltip.Draw();
 	}
 
 	// Draw a warning if the selected system is not routable.
@@ -436,126 +454,16 @@ void MapPanel::FinishDrawing(const string &buttonCondition)
 
 
 
-void MapPanel::DrawMiniMap(const PlayerInfo &player, float alpha, const System *const jump[2], int step)
+bool MapPanel::AllowsFastForward() const noexcept
 {
-	const Font &font = FontSet::Get(14);
-	Color lineColor(alpha, 0.f);
-	Point center = .5 * (jump[0]->Position() + jump[1]->Position());
-	const Point &drawPos = GameData::Interfaces().Get("hud")->GetPoint("mini-map");
-	set<const System *> drawnSystems = { jump[0], jump[1] };
-	bool isLink = jump[0]->Links().contains(jump[1]);
-
-	const Set<Color> &colors = GameData::Colors();
-	const Color &currentColor = colors.Get("active mission")->Additive(alpha * 2.f);
-	const Color &blockedColor = colors.Get("blocked mission")->Additive(alpha * 2.f);
-	const Color &waypointColor = colors.Get("waypoint")->Additive(alpha * 2.f);
-
-	const Ship *flagship = player.Flagship();
-	for(int i = 0; i < 2; ++i)
-	{
-		static const string UNKNOWN_SYSTEM = "Unexplored System";
-		const System &system = *jump[i];
-		const Government *gov = system.GetGovernment();
-		Point from = system.Position() - center + drawPos;
-		const string &name = player.KnowsName(system) ? system.DisplayName() : UNKNOWN_SYSTEM;
-		font.Draw(name, from + Point(OUTER, -.5 * font.Height()), lineColor);
-
-		// Draw the origin and destination systems, since they
-		// might not be linked via hyperspace.
-		Color color = Color(.5f * alpha, 0.f);
-		if(player.CanView(system) && system.IsInhabited(flagship) && gov)
-			color = gov->GetColor().Additive(alpha);
-		RingShader::Draw(from, OUTER, INNER, color);
-
-		for(const System *link : system.Links())
-		{
-			// Only draw systems known to be attached to the jump systems.
-			if(!player.CanView(system) && !player.CanView(*link))
-				continue;
-
-			// Draw the system link. This will double-draw the jump
-			// path if it is via hyperlink, to increase brightness.
-			Point to = link->Position() - center + drawPos;
-			Point unit = (from - to).Unit() * LINK_OFFSET;
-			LineShader::Draw(from - unit, to + unit, LINK_WIDTH, lineColor);
-
-			if(drawnSystems.contains(link))
-				continue;
-			drawnSystems.insert(link);
-
-			gov = link->GetGovernment();
-			Color color = Color(.5f * alpha, 0.f);
-			if(player.CanView(*link) && link->IsInhabited(flagship) && gov)
-				color = gov->GetColor().Additive(alpha);
-			RingShader::Draw(to, OUTER, INNER, color);
-		}
-
-		unsigned missionCounter = 0;
-		for(const Mission &mission : player.Missions())
-		{
-			if(missionCounter >= MAX_MISSION_POINTERS_DRAWN)
-				break;
-
-			if(!mission.IsVisible())
-				continue;
-
-			if(mission.Destination()->IsInSystem(&system))
-			{
-				pair<bool, bool> blink = BlinkMissionIndicator(player, mission, step);
-				if(!blink.first)
-				{
-					bool isSatisfied = IsSatisfied(player, mission) && blink.second;
-					DrawPointer(from, missionCounter, isSatisfied ? currentColor : blockedColor, false);
-				}
-				else
-					++missionCounter;
-			}
-
-			for(const System *waypoint : mission.Waypoints())
-			{
-				if(missionCounter >= MAX_MISSION_POINTERS_DRAWN)
-					break;
-				if(waypoint == &system)
-					DrawPointer(from, missionCounter, waypointColor, false);
-			}
-			for(const Planet *stopover : mission.Stopovers())
-			{
-				if(missionCounter >= MAX_MISSION_POINTERS_DRAWN)
-					break;
-				if(stopover->IsInSystem(&system))
-					DrawPointer(from, missionCounter, waypointColor, false);
-			}
-
-			for(const System *mark : mission.MarkedSystems())
-			{
-				if(missionCounter >= MAX_MISSION_POINTERS_DRAWN)
-					break;
-				if(mark == &system)
-					DrawPointer(from, missionCounter, waypointColor, false);
-			}
-		}
-	}
-
-	// Draw the rest of the directional arrow. If this is a normal jump,
-	// the stem was already drawn above.
-	Point from = jump[0]->Position() - center + drawPos;
-	Point to = jump[1]->Position() - center + drawPos;
-	Point unit = (to - from).Unit();
-	from += LINK_OFFSET * unit;
-	to -= LINK_OFFSET * unit;
-	Color bright(2.f * alpha, 0.f);
-	// Non-hyperspace jumps are drawn with a dashed directional arrow.
-	if(!isLink)
-		LineShader::DrawDashed(from, to, unit, LINK_WIDTH, bright, 11., 4.);
-	LineShader::Draw(to, to + Angle(-30.).Rotate(unit) * -10., LINK_WIDTH, bright);
-	LineShader::Draw(to, to + Angle(30.).Rotate(unit) * -10., LINK_WIDTH, bright);
+	return true;
 }
 
 
 
-bool MapPanel::AllowsFastForward() const noexcept
+void MapPanel::UpdateTooltipActivation()
 {
-	return true;
+	tooltip.UpdateActivationCount();
 }
 
 
@@ -568,7 +476,6 @@ bool MapPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &command, bool
 		for(auto &child : GetChildren())
 			RemoveChild(child.get());
 	};
-	const Interface *mapInterface = GameData::Interfaces().Get("map");
 	if(command.Has(Command::MAP) || key == 'd' || key == SDLK_ESCAPE
 			|| (key == 'w' && (mod & (KMOD_CTRL | KMOD_GUI))))
 		GetUI()->Pop(this);
@@ -609,9 +516,9 @@ bool MapPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &command, bool
 		return true;
 	}
 	else if(key == SDLK_PLUS || key == SDLK_KP_PLUS || key == SDLK_EQUALS)
-		player.SetMapZoom(min<int>(mapInterface->GetValue("max zoom"), player.MapZoom() + 1));
+		IncrementZoom();
 	else if(key == SDLK_MINUS || key == SDLK_KP_MINUS)
-		player.SetMapZoom(max<int>(mapInterface->GetValue("min zoom"), player.MapZoom() - 1));
+		DecrementZoom();
 	else
 		return false;
 
@@ -621,8 +528,11 @@ bool MapPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &command, bool
 
 
 
-bool MapPanel::Click(int x, int y, int clicks)
+bool MapPanel::Click(int x, int y, MouseButton button, int clicks)
 {
+	if(button != MouseButton::LEFT)
+		return false;
+
 	// Figure out if a system was clicked on.
 	Point click = Point(x, y) / Zoom() - center;
 	for(const auto &it : GameData::Systems())
@@ -659,7 +569,7 @@ bool MapPanel::Hover(int x, int y)
 			return true;
 
 		hoverSystem = nullptr;
-		tooltip.clear();
+		tooltip.Clear();
 	}
 
 	// Check if the new position supports a tooltip.
@@ -691,18 +601,11 @@ bool MapPanel::Drag(double dx, double dy)
 
 bool MapPanel::Scroll(double dx, double dy)
 {
-	// The mouse should be pointing to the same map position before and after zooming.
-	Point mouse = UI::GetMouse();
-	Point anchor = mouse / Zoom() - center;
-	const Interface *mapInterface = GameData::Interfaces().Get("map");
 	if(dy > 0.)
-		player.SetMapZoom(min<int>(mapInterface->GetValue("max zoom"), player.MapZoom() + 1));
+		IncrementZoom();
 	else if(dy < 0.)
-		player.SetMapZoom(max<int>(mapInterface->GetValue("min zoom"), player.MapZoom() - 1));
+		DecrementZoom();
 
-	// Now, Zoom() has changed (unless at one of the limits). But, we still want
-	// anchor to be the same, so:
-	center = mouse / Zoom() - anchor;
 	return true;
 }
 
@@ -912,7 +815,7 @@ void MapPanel::Find(const string &name)
 
 double MapPanel::Zoom() const
 {
-	return pow(1.5, player.MapZoom());
+	return pow(1.5, zoom.AnimatedValue());
 }
 
 
@@ -1457,7 +1360,7 @@ void MapPanel::DrawSystems()
 			}
 		}
 
-		if(commodity == SHOW_GOVERNMENT && node.government && node.government->GetName() != "Uninhabited")
+		if(commodity == SHOW_GOVERNMENT && node.government && node.government->DisplayName() != "Uninhabited")
 		{
 			// For every government that is drawn, keep track of how close it
 			// is to the center of the view. The four closest governments
@@ -1478,17 +1381,17 @@ void MapPanel::DrawSystems()
 
 void MapPanel::DrawNames()
 {
-	// Don't draw if too small.
-	double zoom = Zoom();
-	if(zoom <= 0.5)
-		return;
-
 	// Draw names for all systems you have visited.
+	double zoom = Zoom();
+	if(zoom <= .5)
+		return;
+	static constexpr double BIGGER_TARGET_ZOOM = 2. / 3.;
+	double alpha = zoom >= BIGGER_TARGET_ZOOM ? 1. : (.5 - zoom) / (.5 - BIGGER_TARGET_ZOOM);
 	bool useBigFont = (zoom > 2.);
 	const Font &font = FontSet::Get(useBigFont ? 18 : 14);
 	Point offset(useBigFont ? 8. : 6., -.5 * font.Height());
 	for(const Node &node : nodes)
-		font.Draw(node.name, zoom * (node.position + center) + offset, node.nameColor);
+		font.Draw(node.name, zoom * (node.position + center) + offset, node.nameColor.Transparent(alpha));
 }
 
 
@@ -1579,12 +1482,19 @@ void MapPanel::DrawPointer(const System *system, unsigned &systemCount, unsigned
 
 
 
-void MapPanel::DrawPointer(Point position, unsigned &systemCount, const Color &color, bool drawBack, bool bigger)
+void MapPanel::IncrementZoom()
 {
-	if(++systemCount > MAX_MISSION_POINTERS_DRAWN)
-		return;
-	Angle angle = Angle(MISSION_POINTERS_ANGLE_DELTA * systemCount);
-	if(drawBack)
-		PointerShader::Draw(position, angle.Unit(), 14.f + bigger, 19.f + 2 * bigger, -4.f, black);
-	PointerShader::Draw(position, angle.Unit(), 8.f + bigger, 15.f + 2 * bigger, -6.f, color);
+	const Interface *mapInterface = GameData::Interfaces().Get("map");
+	double newZoom = min<double>(mapInterface->GetValue("max zoom"), player.MapZoom() + 1);
+	zoom.Set(newZoom, mapInterface->GetValue("zoom animation duration"));
+	player.SetMapZoom(newZoom);
+}
+
+
+void MapPanel::DecrementZoom()
+{
+	const Interface *mapInterface = GameData::Interfaces().Get("map");
+	double newZoom = max<double>(mapInterface->GetValue("min zoom"), player.MapZoom() - 1);
+	zoom.Set(newZoom, mapInterface->GetValue("zoom animation duration"));
+	player.SetMapZoom(newZoom);
 }
