@@ -13,8 +13,7 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef MENU_ANIMATION_PANEL_H_
-#define MENU_ANIMATION_PANEL_H_
+#pragma once
 
 #include "Panel.h"
 
@@ -33,7 +32,3 @@ public:
 private:
 	float alpha = 1.f;
 };
-
-
-
-#endif
