@@ -137,13 +137,13 @@ void Mission::Load(const DataNode &node, const ConditionsStore *playerConditions
 	// due to a plugin containing a mission with the same name as the base game
 	// or another plugin). This class is not designed to allow merging or
 	// overriding of mission data from two different definitions.
-	if(!name.empty())
+	if(!trueName.empty())
 	{
 		node.PrintTrace("Error: Duplicate definition of mission:");
 		return;
 	}
-	name = node.Token(1);
-	if(!DataNode::IsConditionName(name))
+	trueName = node.Token(1);
+	if(!DataNode::IsConditionName(trueName))
 		node.PrintTrace("Error: Invalid mission name");
 
 	for(const DataNode &child : node)
@@ -381,7 +381,7 @@ void Mission::Load(const DataNode &node, const ConditionsStore *playerConditions
 	}
 
 	if(displayName.empty())
-		displayName = name;
+		displayName = trueName;
 }
 
 
@@ -390,7 +390,7 @@ void Mission::Load(const DataNode &node, const ConditionsStore *playerConditions
 // is already "instantiated," so only a subset of the data must be saved.
 void Mission::Save(DataWriter &out, const string &tag) const
 {
-	out.Write(tag, name);
+	out.Write(tag, trueName);
 	out.BeginChild();
 	{
 		out.Write("name", displayName);
@@ -416,8 +416,8 @@ void Mission::Save(DataWriter &out, const string &tag) const
 		auto saveColor = [&out](const ExclusiveItem<Color> &color, string tokenName) noexcept -> void {
 			if(!color->IsLoaded())
 				return;
-			if(!color->Name().empty())
-				out.Write("color", tokenName, color->Name());
+			if(!color->TrueName().empty())
+				out.Write("color", tokenName, color->TrueName());
 			else
 			{
 				const float *rgba = color->Get();
@@ -570,7 +570,17 @@ const EsUuid &Mission::UUID() const noexcept
 
 
 
-const string &Mission::Name() const
+// Get the internal name used for this mission. This name is unique and is
+// never modified by string substitution, so it can be used in condition
+// variables, etc.
+const string &Mission::TrueName() const
+{
+	return trueName;
+}
+
+
+
+const string &Mission::DisplayName() const
 {
 	return displayName;
 }
@@ -931,7 +941,7 @@ bool Mission::CanOffer(const PlayerInfo &player, const shared_ptr<Ship> &boardin
 	if(!toFail.IsEmpty() && toFail.Test())
 		return false;
 
-	if(repeat && player.Conditions().Get(name + ": offered") >= repeat)
+	if(repeat && player.Conditions().Get(trueName + ": offered") >= repeat)
 		return false;
 
 	bool isFailed = IsFailed();
@@ -1197,16 +1207,16 @@ bool Mission::Do(Trigger trigger, PlayerInfo &player, UI *ui, const shared_ptr<S
 	// not prevent a mission from being failed or aborted.
 	if(trigger == FAIL)
 	{
-		--player.Conditions()[name + ": active"];
-		++player.Conditions()[name + ": failed"];
+		--player.Conditions()[trueName + ": active"];
+		++player.Conditions()[trueName + ": failed"];
 	}
 	else if(trigger == ABORT)
 	{
-		--player.Conditions()[name + ": active"];
-		++player.Conditions()[name + ": aborted"];
+		--player.Conditions()[trueName + ": active"];
+		++player.Conditions()[trueName + ": aborted"];
 		// Set the failed mission condition here as well for
 		// backwards compatibility.
-		++player.Conditions()[name + ": failed"];
+		++player.Conditions()[trueName + ": failed"];
 	}
 
 	// Don't update any further conditions if this action exists and can't be completed.
@@ -1215,8 +1225,8 @@ bool Mission::Do(Trigger trigger, PlayerInfo &player, UI *ui, const shared_ptr<S
 
 	if(trigger == ACCEPT)
 	{
-		++player.Conditions()[name + ": offered"];
-		++player.Conditions()[name + ": active"];
+		++player.Conditions()[trueName + ": offered"];
+		++player.Conditions()[trueName + ": active"];
 		// Any potential on offer conversation has been finished, so update
 		// the active NPCs for the first time.
 		UpdateNPCs(player);
@@ -1228,13 +1238,13 @@ bool Mission::Do(Trigger trigger, PlayerInfo &player, UI *ui, const shared_ptr<S
 	}
 	else if(trigger == DECLINE)
 	{
-		++player.Conditions()[name + ": offered"];
-		++player.Conditions()[name + ": declined"];
+		++player.Conditions()[trueName + ": offered"];
+		++player.Conditions()[trueName + ": declined"];
 	}
 	else if(trigger == COMPLETE)
 	{
-		--player.Conditions()[name + ": active"];
-		++player.Conditions()[name + ": done"];
+		--player.Conditions()[trueName + ": active"];
+		++player.Conditions()[trueName + ": done"];
 	}
 
 	// "Jobs" should never show dialogs when offered, nor should they call the
@@ -1337,7 +1347,7 @@ void Mission::Do(const ShipEvent &event, PlayerInfo &player, UI *ui)
 				failed |= (it.first == this);
 			if(failed)
 				message = "Your " + event.Target()->DisplayModelName() +
-					" \"" + event.Target()->Name() + "\" has been plundered. ";
+					" \"" + event.Target()->GivenName() + "\" has been plundered. ";
 		}
 
 		if(failed)
@@ -1374,16 +1384,6 @@ void Mission::Do(const ShipEvent &event, PlayerInfo &player, UI *ui)
 
 
 
-// Get the internal name used for this mission. This name is unique and is
-// never modified by string substitution, so it can be used in condition
-// variables, etc.
-const string &Mission::Identifier() const
-{
-	return name;
-}
-
-
-
 // Get a specific mission action from this mission.
 // If a mission action is not found for the given trigger, returns an empty
 // mission action.
@@ -1416,7 +1416,7 @@ Mission Mission::Instantiate(const PlayerInfo &player, const shared_ptr<Ship> &b
 	result.overridesCapture = overridesCapture;
 	result.sourceShip = boardingShip.get();
 	result.repeat = repeat;
-	result.name = name;
+	result.trueName = trueName;
 	result.waypoints = waypoints;
 	result.completionFilter = completionFilter;
 	result.markedSystems = markedSystems;
@@ -1555,7 +1555,7 @@ Mission Mission::Instantiate(const PlayerInfo &player, const shared_ptr<Ship> &b
 	if(player.GetPlanet())
 		subs["<origin>"] = player.GetPlanet()->DisplayName();
 	else if(boardingShip)
-		subs["<origin>"] = boardingShip->Name();
+		subs["<origin>"] = boardingShip->GivenName();
 	subs["<planet>"] = result.destination ? result.destination->DisplayName() : "";
 	subs["<system>"] = result.destination ? result.destination->GetSystem()->DisplayName() : "";
 	subs["<destination>"] = subs["<planet>"] + " in the " + subs["<system>"] + " system";
@@ -1563,46 +1563,25 @@ Mission Mission::Instantiate(const PlayerInfo &player, const shared_ptr<Ship> &b
 	subs["<day>"] = result.deadline.LongString();
 	if(result.paymentApparent)
 		subs["<payment>"] = Format::CreditString(abs(result.paymentApparent));
-	// Stopover and waypoint substitutions: iterate by reference to the
-	// pointers so we can check when we're at the very last one in the set.
 	// Stopovers: "<name> in the <system name> system" with "," and "and".
+	auto getDisplayName = [](const auto *const &item)
+	{
+		return item->DisplayName();
+	};
 	if(!result.stopovers.empty())
 	{
-		string stopovers;
-		string planets;
-		const Planet * const *last = &*--result.stopovers.end();
-		int count = 0;
-		for(const Planet * const &planet : result.stopovers)
-		{
-			if(count++)
+		subs["<stopovers>"] = Format::List<set, const Planet *>(result.stopovers,
+			[](const Planet *const &planet)
 			{
-				string result = (&planet != last) ? ", " : (count > 2 ? ", and " : " and ");
-				stopovers += result;
-				planets += result;
-			}
-			stopovers += planet->DisplayName() + " in the " + planet->GetSystem()->DisplayName() + " system";
-			planets += planet->DisplayName();
-		}
-		subs["<stopovers>"] = stopovers;
-		subs["<planet stopovers>"] = planets;
+				return planet->DisplayName() + " in the " + planet->GetSystem()->DisplayName() + " system";
+			});
+		subs["<planet stopovers>"] = Format::List<set, const Planet *>(result.stopovers, getDisplayName);
 	}
 	// Waypoints and marks: "<system name>" with "," and "and".
-	auto systemsReplacement = [](const set<const System *> &systemsSet) -> string {
-		string systems;
-		const System * const *last = &*--systemsSet.end();
-		int count = 0;
-		for(const System * const &system : systemsSet)
-		{
-			if(count++)
-				systems += (&system != last) ? ", " : (count > 2 ? ", and " : " and ");
-			systems += system->DisplayName();
-		}
-		return systems;
-	};
 	if(!result.waypoints.empty())
-		subs["<waypoints>"] = systemsReplacement(result.waypoints);
+		subs["<waypoints>"] = Format::List<set, const System *>(result.waypoints, getDisplayName);
 	if(!result.markedSystems.empty())
-		subs["<marks>"] = systemsReplacement(result.markedSystems);
+		subs["<marks>"] = Format::List<set, const System *>(result.markedSystems, getDisplayName);
 
 	// Done making subs, so expand the phrases and recursively substitute.
 	for(const auto &keyValue : subs)
@@ -1616,7 +1595,7 @@ Mission Mission::Instantiate(const PlayerInfo &player, const shared_ptr<Ship> &b
 	if(!reason.empty())
 	{
 		Logger::LogError("Instantiation Error: NPC template in mission \""
-			+ Identifier() + "\" uses invalid " + std::move(reason));
+			+ TrueName() + "\" uses invalid " + std::move(reason));
 		return result;
 	}
 	for(const NPC &npc : npcs)
@@ -1634,7 +1613,7 @@ Mission Mission::Instantiate(const PlayerInfo &player, const shared_ptr<Ship> &b
 	if(ait != actions.end())
 	{
 		Logger::LogError("Instantiation Error: Action \"" + TriggerToText(ait->first) + "\" in mission \""
-			+ Identifier() + "\" uses invalid " + std::move(reason));
+			+ TrueName() + "\" uses invalid " + std::move(reason));
 		return result;
 	}
 	for(const auto &it : actions)
@@ -1650,7 +1629,7 @@ Mission Mission::Instantiate(const PlayerInfo &player, const shared_ptr<Ship> &b
 	if(oit != onEnter.end())
 	{
 		Logger::LogError("Instantiation Error: Action \"on enter '" + oit->first->TrueName() + "'\" in mission \""
-			+ Identifier() + "\" uses invalid " + std::move(reason));
+			+ TrueName() + "\" uses invalid " + std::move(reason));
 		return result;
 	}
 	for(const auto &it : onEnter)
@@ -1666,7 +1645,7 @@ Mission Mission::Instantiate(const PlayerInfo &player, const shared_ptr<Ship> &b
 	if(eit != genericOnEnter.end())
 	{
 		Logger::LogError("Instantiation Error: Generic \"on enter\" action in mission \""
-			+ Identifier() + "\" uses invalid " + std::move(reason));
+			+ TrueName() + "\" uses invalid " + std::move(reason));
 		return result;
 	}
 	for(const MissionAction &action : genericOnEnter)
