@@ -16,7 +16,6 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #pragma once
 
 #include "ConditionSet.h"
-#include "ConditionsStore.h"
 #include "Conversation.h"
 #include "ExclusiveItem.h"
 #include "GameAction.h"
@@ -27,10 +26,12 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include <string>
 #include <vector>
 
+class ConditionsStore;
 class DataNode;
 class DataWriter;
 class Mission;
 class Outfit;
+class Planet;
 class PlayerInfo;
 class System;
 class UI;
@@ -45,10 +46,13 @@ class MissionAction {
 public:
 	MissionAction() = default;
 	// Construct and Load() at the same time.
-	MissionAction(const DataNode &node);
+	MissionAction(const DataNode &node, const ConditionsStore *playerConditions,
+		const std::set<const System *> *visitedSystems, const std::set<const Planet *> *visitedPlanets);
 
-	void Load(const DataNode &node);
-	void LoadSingle(const DataNode &node);
+	void Load(const DataNode &node, const ConditionsStore *playerConditions,
+		const std::set<const System *> *visitedSystems, const std::set<const Planet *> *visitedPlanets);
+	void LoadSingle(const DataNode &node, const ConditionsStore *playerConditions,
+		const std::set<const System *> *visitedSystems, const std::set<const Planet *> *visitedPlanets);
 	// Note: the Save() function can assume this is an instantiated mission, not
 	// a template, so it only has to save a subset of the data.
 	void Save(DataWriter &out) const;
@@ -61,7 +65,7 @@ public:
 	// Check if this action can be completed right now. It cannot be completed
 	// if it takes away money or outfits that the player does not have, or should
 	// take place in a system that does not match the specified LocationFilter.
-	// It can also not be done if the mission is failed, and teh trigger doesn't support it.
+	// It can also not be done if the mission is failed, and the trigger doesn't support it.
 	bool CanBeDone(const PlayerInfo &player, bool isFailed, const std::shared_ptr<Ship> &boardingShip = nullptr) const;
 	// Check if this action requires this ship to exist in order to ever be completed.
 	bool RequiresGiftedShip(const std::string &shipId) const;
@@ -73,7 +77,7 @@ public:
 
 	// "Instantiate" this action by filling in the wildcard text for the actual
 	// destination, payment, cargo, etc.
-	MissionAction Instantiate(const ConditionsStore &store, std::map<std::string, std::string> &subs,
+	MissionAction Instantiate(std::map<std::string, std::string> &subs,
 		const System *origin, int jumps, int64_t payload) const;
 
 	int64_t Payment() const noexcept;
@@ -84,7 +88,7 @@ private:
 	public:
 		MissionDialog(const ExclusiveItem<Phrase> &);
 		MissionDialog(const std::string &);
-		MissionDialog(const DataNode &);
+		MissionDialog(const DataNode &, const ConditionsStore *);
 
 
 		std::string dialogText;
@@ -94,7 +98,7 @@ private:
 
 
 private:
-	std::string CollapseDialog(const ConditionsStore *store, const std::map<std::string, std::string> *subs) const;
+	std::string CollapseDialog(const std::map<std::string, std::string> *subs) const;
 
 
 private:
