@@ -57,8 +57,8 @@ public:
 	bool IsDefined() const;
 
 	const std::string &TrueName() const;
+	void SetTrueName(const std::string &name);
 	const std::string &DisplayName() const;
-	void SetName(const std::string &name);
 	const std::string &PluralName() const;
 	const std::string &Category() const;
 	const std::string &Series() const;
