@@ -647,18 +647,10 @@ void OutfitInfoDisplay::UpdateAttributes(const Outfit &outfit)
 		attributeValues.emplace_back(Format::Number(arc));
 		attributesHeight += 20;
 	}
-	int homing = outfit.Homing();
-	if(homing)
+	if(outfit.Homing())
 	{
-		static const string skill[] = {
-			"none",
-			"poor",
-			"fair",
-			"good",
-			"excellent"
-		};
-		attributeLabels.emplace_back("homing:");
-		attributeValues.push_back(skill[max(0, min(4, homing))]);
+		attributeLabels.emplace_back("homing type:");
+		attributeValues.emplace_back(outfit.Leading() ? "leading" : "direct");
 		attributesHeight += 20;
 	}
 	static const vector<string> PERCENT_NAMES = {
@@ -683,6 +675,18 @@ void OutfitInfoDisplay::UpdateAttributes(const Outfit &outfit)
 			attributeValues.push_back(Format::Number(percent) + "%");
 			attributesHeight += 20;
 		}
+	if(outfit.ThrottleControl())
+	{
+		attributeLabels.emplace_back("Projectiles can control thrust.");
+		attributeValues.emplace_back(" ");
+		attributesHeight += 20;
+	}
+	if(outfit.HasBlindspot())
+	{
+		attributeLabels.emplace_back("Cannot track targets behind it.");
+		attributeValues.emplace_back(" ");
+		attributesHeight += 20;
+	}
 
 	// Pad the table.
 	attributeLabels.emplace_back();
