@@ -15,7 +15,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 
 #include "OutfitterPanel.h"
 
-#include "text/alignment.hpp"
+#include "text/Alignment.h"
 #include "comparators/BySeriesAndIndex.h"
 #include "Color.h"
 #include "Dialog.h"
@@ -35,7 +35,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "image/Sprite.h"
 #include "image/SpriteSet.h"
 #include "shader/SpriteShader.h"
-#include "text/truncate.hpp"
+#include "text/Truncate.h"
 #include "UI.h"
 
 #include <algorithm>
@@ -78,8 +78,8 @@ namespace {
 
 
 
-OutfitterPanel::OutfitterPanel(PlayerInfo &player)
-	: ShopPanel(player, true)
+OutfitterPanel::OutfitterPanel(PlayerInfo &player, Sale<Outfit> stock)
+	: ShopPanel(player, true), outfitter(stock)
 {
 	for(const pair<const string, Outfit> &it : GameData::Outfits())
 		catalog[it.second.Category()].push_back(it.first);
@@ -87,9 +87,6 @@ OutfitterPanel::OutfitterPanel(PlayerInfo &player)
 	for(pair<const string, vector<string>> &it : catalog)
 		sort(it.second.begin(), it.second.end(), BySeriesAndIndex<Outfit>());
 
-	if(player.GetPlanet())
-		outfitter = player.GetPlanet()->Outfitter();
-
 	for(auto &ship : player.Ships())
 		if(ship->GetPlanet() == planet)
 			++shipsHere;
@@ -178,7 +175,10 @@ void OutfitterPanel::DrawItem(const string &name, const Point &point)
 		if(isLicense)
 			minCount = maxCount = player.HasLicense(LicenseRoot(name));
 		else if(mapSize)
-			minCount = maxCount = player.HasMapped(mapSize);
+		{
+			bool mapMinables = outfit->Get("map minables");
+			minCount = maxCount = player.HasMapped(mapSize, mapMinables);
+		}
 		else
 		{
 			highlightDifferences = true;
@@ -281,7 +281,7 @@ double OutfitterPanel::DrawDetails(const Point &center)
 		const Point thumbnailCenter(center.X(), center.Y() + 20 + static_cast<int>(tileSize / 2));
 		const Point startPoint(center.X() - INFOBAR_WIDTH / 2 + 20, center.Y() + 20 + tileSize);
 
-		const Sprite *background = SpriteSet::Get("ui/outfitter selected");
+		const Sprite *background = SpriteSet::Get("ui/outfitter unselected");
 		SpriteShader::Draw(background, thumbnailCenter);
 		if(thumbnail)
 			SpriteShader::Draw(thumbnail, thumbnailCenter);
@@ -339,7 +339,8 @@ ShopPanel::BuyResult OutfitterPanel::CanBuy(bool onlyOwned) const
 
 	// Check special unique outfits, if you already have them.
 	int mapSize = selectedOutfit->Get("map");
-	if(mapSize > 0 && player.HasMapped(mapSize))
+	bool mapMinables = selectedOutfit->Get("map minables");
+	if(mapSize > 0 && player.HasMapped(mapSize, mapMinables))
 		return "You have already mapped all the systems shown by this map, "
 			"so there is no reason to buy another.";
 
@@ -403,13 +404,13 @@ ShopPanel::BuyResult OutfitterPanel::CanBuy(bool onlyOwned) const
 
 		if(cost > credits)
 			errors.push_back("You do not have enough money to buy this outfit. You need a further " +
-				Format::CreditString(cost - credits));
+				Format::CreditString(cost - credits) + ".");
 
 		// Add the cost to buy the required license.
 		else if(cost + licenseCost > credits)
 			errors.push_back("You do not have enough money to buy this outfit because you also need "
 				"to buy a license for it. You need a further " +
-				Format::CreditString(cost + licenseCost - credits));
+				Format::CreditString(cost + licenseCost - credits) + ".");
 	}
 
 	bool anyShipCanInstall = true;
@@ -523,7 +524,8 @@ void OutfitterPanel::Buy(bool onlyOwned)
 	int mapSize = selectedOutfit->Get("map");
 	if(mapSize)
 	{
-		player.Map(mapSize);
+		bool mapMinables = selectedOutfit->Get("map minables");
+		player.Map(mapSize, mapMinables);
 		player.Accounts().AddCredits(-selectedOutfit->Cost());
 		return;
 	}
@@ -883,13 +885,7 @@ void OutfitterPanel::DrawOutfit(const Outfit &outfit, const Point &center, bool
 
 bool OutfitterPanel::IsLicense(const string &name) const
 {
-	static const string &LICENSE = " License";
-	if(name.length() < LICENSE.length())
-		return false;
-	if(name.compare(name.length() - LICENSE.length(), LICENSE.length(), LICENSE))
-		return false;
-
-	return true;
+	return name.ends_with(" License");
 }
 
 
