@@ -38,6 +38,7 @@ public:
 		const std::set<const System *> *visitedSystems, const std::set<const Planet *> *visitedPlanets);
 	// Finish loading all the ships in this person specification.
 	void FinishLoading();
+	bool IsLoaded() const;
 	// Prevent this person from being spawned in any system.
 	void NeverSpawn();
 
@@ -64,6 +65,7 @@ public:
 
 
 private:
+	bool isLoaded = false;
 	LocationFilter location;
 	int frequency = 100;
 
