@@ -65,6 +65,7 @@ namespace {
 		RESTRICTED,
 		DECLOAKED,
 		QUIET,
+		GETAWAY,
 
 		// This must be last so it can be used for bounds checking.
 		LAST_ITEM_IN_PERSONALITY_TRAIT_ENUM
@@ -107,7 +108,8 @@ namespace {
 		{"unrestricted", UNRESTRICTED},
 		{"restricted", RESTRICTED},
 		{"decloaked", DECLOAKED},
-		{"quiet", QUIET}
+		{"quiet", QUIET},
+		{"getaway", GETAWAY}
 	};
 
 	// Tokens that combine two or more flags.
@@ -309,6 +311,13 @@ bool Personality::IsRamming() const
 
 
 
+bool Personality::IsGetaway() const
+{
+	return flags.test(GETAWAY);
+}
+
+
+
 bool Personality::IsStaying() const
 {
 	return flags.test(STAYING);
