@@ -24,9 +24,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "Depreciation.h"
 #include "EsUuid.h"
 #include "GameEvent.h"
-#include "Government.h"
 #include "Mission.h"
-#include "RaidFleet.h"
 #include "SystemEntry.h"
 
 #include <chrono>
@@ -39,8 +37,10 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include <utility>
 #include <vector>
 
+class DistanceMap;
 class Outfit;
 class Planet;
+class RaidFleet;
 class Rectangle;
 class Ship;
 class ShipEvent;
@@ -63,6 +63,12 @@ public:
 		int64_t maintenanceCosts = 0;
 		int64_t assetsReturns = 0;
 	};
+	enum SortType {
+		ABC,
+		PAY,
+		SPEED,
+		CONVENIENT
+	};
 
 
 public:
@@ -70,7 +76,7 @@ public:
 	// Don't allow copying this class.
 	PlayerInfo(const PlayerInfo &) = delete;
 	PlayerInfo &operator=(const PlayerInfo &) = delete;
-	PlayerInfo(PlayerInfo &&) = default;
+	PlayerInfo(PlayerInfo &&) = delete;
 	PlayerInfo &operator=(PlayerInfo &&) = default;
 	~PlayerInfo() noexcept = default;
 
@@ -99,7 +105,7 @@ public:
 	void FinishTransaction();
 
 	// Apply the given changes and store them in the player's saved game file.
-	void AddChanges(std::list<DataNode> &changes);
+	void AddChanges(std::list<DataNode> &changes, bool instantChanges = false);
 	// Add an event that will happen at the given date.
 	void AddEvent(GameEvent event, const Date &date);
 
@@ -218,8 +224,20 @@ public:
 	// Get mission information.
 	const std::list<Mission> &Missions() const;
 	const std::list<Mission> &AvailableJobs() const;
+	bool HasAvailableEnteringMissions() const;
+
+	// Determine how many days left the player has for each mission with a deadline, for
+	// the purpose of determining how frequently the MapPanel should blink the mission
+	// marker.
+	void CalculateRemainingDeadlines();
+	// Add a mission that was just accepted to the cached remaining deadlines.
+	void CalculateRemainingDeadline(const Mission &mission, DistanceMap &here);
+	// The number of days left before this mission's deadline has elapsed, or,
+	// if the "Deadline blink by distance" preference is true, before the player
+	// doesn't have enough days left to complete the mission before the deadline
+	// will elapse. Returns 0 if the give mission doesn't have a deadline.
+	int RemainingDeadline(const Mission &mission) const;
 
-	enum SortType {ABC, PAY, SPEED, CONVENIENT};
 	const SortType GetAvailableSortType() const;
 	void NextAvailableSortType();
 	const bool ShouldSortAscending() const;
@@ -230,20 +248,25 @@ public:
 	void ToggleSortSeparatePossible();
 	void SortAvailable();
 
-	const Mission *ActiveBoardingMission() const;
+	const Mission *ActiveInFlightMission() const;
 	void UpdateMissionNPCs();
 	void AcceptJob(const Mission &mission, UI *ui);
 	// Check to see if there is any mission to offer right now.
 	Mission *MissionToOffer(Mission::Location location);
 	Mission *BoardingMission(const std::shared_ptr<Ship> &ship);
+	void CreateEnteringMissions();
+	Mission *EnteringMission();
 	// Return true if the given ship is capturable only because it's the source
 	// of a boarding mission which allows it to be.
 	bool CaptureOverriden(const std::shared_ptr<Ship> &ship) const;
-	void ClearActiveBoardingMission();
+	void ClearActiveInFlightMission();
 	// If one of your missions cannot be offered because you do not have enough
 	// space for it, and it specifies a message to be shown in that situation,
 	// show that message.
 	void HandleBlockedMissions(Mission::Location location, UI *ui);
+	// Display the blocked message for the first available entering mission,
+	// then remove it from the available entering missions list.
+	void HandleBlockedEnteringMissions(UI *ui);
 	// Callback for accepting or declining whatever mission has been offered.
 	void MissionCallback(int response);
 	// Basic callback for handling forced departure from a planet.
@@ -281,11 +304,13 @@ public:
 	// Mark a system and its planets as unvisited, even if visited previously.
 	void Unvisit(const System &system);
 	void Unvisit(const Planet &planet);
+	const std::set<const System *> &VisitedSystems() const;
+	const std::set<const Planet *> &VisitedPlanets() const;
 
 	// Check whether the player has visited the <mapSize> systems around the current one.
-	bool HasMapped(int mapSize) const;
+	bool HasMapped(int mapSize, bool mapMinables) const;
 	// Mark a whole map of systems as visited.
-	void Map(int mapSize);
+	void Map(int mapSize, bool mapMinables);
 
 	// Access the player's travel plan.
 	bool HasTravelPlan() const;
@@ -366,6 +391,8 @@ private:
 	// Set the flagship (on departure or during flight).
 	void SetFlagship(Ship &other);
 
+	void HandleFlagshipParking(Ship *oldFirstShip, Ship *newFirstShip);
+
 	// Helper function to update the ship selection.
 	void SelectShip(const std::shared_ptr<Ship> &ship, bool *first);
 
@@ -379,6 +406,8 @@ private:
 	// Handle the daily salaries and payments.
 	void DoAccounting();
 
+	bool HasClearance() const;
+
 
 private:
 	std::string firstName;
@@ -418,16 +447,28 @@ private:
 	// they will not change if you reload the game.
 	std::list<Mission> availableJobs;
 	std::list<Mission> availableMissions;
+	// This list is populated upon entering a system, and isn't saved since
+	// you can't save in space.
+	std::list<Mission> availableEnteringMissions;
+	// This list is populated upon boarding a ship, and isn't saved since
+	// you can't save in space. As of right now, only one boarding mission
+	// can be offered at a time, so this list will only ever contain one or
+	// zero missions.
+	std::list<Mission> availableBoardingMissions;
 	// If any mission component is not fully defined, the mission is deactivated
 	// until its components are fully evaluable (i.e. needed plugins are reinstalled).
 	std::list<Mission> inactiveMissions;
 	// Missions that are failed or aborted, but not yet deleted, and any
 	// missions offered while in-flight are not saved.
 	std::list<Mission> doneMissions;
-	std::list<Mission> boardingMissions;
-	// This pointer to the most recently accepted boarding mission enables
-	// its NPCs to be placed before the player lands, and is then cleared.
-	Mission *activeBoardingMission = nullptr;
+	// This pointer to the most recently accepted boarding/assisting/entering mission
+	// enables its NPCs to be placed before the player lands, and is then cleared.
+	Mission *activeInFlightMission = nullptr;
+	// For each active mission with a deadline, calculate how many days the player
+	// has left to compelete the mission. The number of days remaining is reduced
+	// by the number of days of travel it will take to complete the mission if the
+	// "Deadline blink by distance" preference is true.
+	std::map<const Mission *, int> remainingDeadlines;
 	// How to sort availableJobs
 	bool availableSortAsc = true;
 	SortType availableSortType;
