@@ -26,6 +26,10 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "Logger.h"
 #include "Screen.h"
 
+#ifdef _WIN32
+#include "windows/WinVersion.h"
+#endif
+
 #include <algorithm>
 #include <cstddef>
 #include <map>
@@ -35,6 +39,7 @@ using namespace std;
 namespace {
 	map<string, bool> settings;
 	int scrollSpeed = 60;
+	int tooltipActivation = 60;
 
 	// Strings for ammo expenditure:
 	const string EXPEND_AMMO = "Escorts expend ammo";
@@ -164,7 +169,21 @@ namespace {
 	const vector<string> ALERT_INDICATOR_SETTING = {"off", "audio", "visual", "both"};
 	int alertIndicatorIndex = 3;
 
+	const vector<string> MINIMAP_DISPLAY_SETTING = {"off", "when jumping", "always on"};
+	int minimapDisplayIndex = 1;
+
+	const vector<string> FLAGSHIP_SPACE_PRIORITY_SETTINGS = {"none", "passengers", "cargo", "both"};
+	int flagshipSpacePriorityIndex = 1;
+
 	int previousSaveCount = 3;
+
+#ifdef _WIN32
+	const vector<string> TITLE_BAR_THEME_SETTINGS = {"system default", "light", "dark"};
+	int titleBarThemeIndex = 0;
+
+	const vector<string> WINDOW_ROUNDING_SETTINGS = {"system default", "off", "large", "small"};
+	int windowRoundingIndex = 0;
+#endif
 }
 
 
@@ -181,7 +200,6 @@ void Preferences::Load()
 	settings["Damaged fighters retreat"] = true;
 	settings["Show escort systems on map"] = true;
 	settings["Show stored outfits on map"] = true;
-	settings["Show mini-map"] = true;
 	settings["Show planet labels"] = true;
 	settings["Show asteroid scanner overlay"] = true;
 	settings["Show hyperspace flash"] = true;
@@ -209,6 +227,8 @@ void Preferences::Load()
 			Audio::SetVolume(node.Value(1) * VOLUME_SCALE, VOLUME_SETTINGS.at(key));
 		else if(key == "scroll speed" && hasValue)
 			scrollSpeed = node.Value(1);
+		else if(key == "Tooltip activation time" && hasValue)
+			tooltipActivation = node.Value(1);
 		else if(key == "boarding target")
 			boardingIndex = max<int>(0, min<int>(node.Value(1), BOARDING_SETTINGS.size() - 1));
 		else if(key == "Flotsam collection")
@@ -245,12 +265,22 @@ void Preferences::Load()
 			dateFormatIndex = max<int>(0, min<int>(node.Value(1), DATEFMT_OPTIONS.size() - 1));
 		else if(key == "alert indicator")
 			alertIndicatorIndex = max<int>(0, min<int>(node.Value(1), ALERT_INDICATOR_SETTING.size() - 1));
+		else if(key == "Show mini-map")
+			minimapDisplayIndex = max<int>(0, min<int>(node.Value(1), MINIMAP_DISPLAY_SETTING.size() - 1));
+		else if(key == "Prioritize flagship use")
+			flagshipSpacePriorityIndex = clamp<int>(node.Value(1), 0, FLAGSHIP_SPACE_PRIORITY_SETTINGS.size() - 1);
 		else if(key == "previous saves" && hasValue)
 			previousSaveCount = max<int>(3, node.Value(1));
 		else if(key == "alt-mouse turning")
 			settings["Control ship with mouse"] = (!hasValue || node.Value(1));
 		else if(key == "notification settings")
 			notifOptionsIndex = max<int>(0, min<int>(node.Value(1), NOTIF_OPTIONS.size() - 1));
+#ifdef _WIN32
+		else if(key == "Title bar theme")
+			titleBarThemeIndex = clamp<int>(node.Value(1), 0, TITLE_BAR_THEME_SETTINGS.size() - 1);
+		else if(key == "Window rounding")
+			windowRoundingIndex = clamp<int>(node.Value(1), 0, WINDOW_ROUNDING_SETTINGS.size() - 1);
+#endif
 		else
 			settings[key] = (node.Size() == 1 || node.Value(1));
 	}
@@ -297,6 +327,7 @@ void Preferences::Save()
 	out.Write("window size", Screen::RawWidth(), Screen::RawHeight());
 	out.Write("zoom", Screen::UserZoom());
 	out.Write("scroll speed", scrollSpeed);
+	out.Write("Tooltip activation time", tooltipActivation);
 	out.Write("boarding target", boardingIndex);
 	out.Write("Flotsam collection", flotsamIndex);
 	out.Write("view zoom", zoomIndex);
@@ -315,7 +346,15 @@ void Preferences::Save()
 	out.Write("Parallax background", parallaxIndex);
 	out.Write("Extended jump effects", extendedJumpEffectIndex);
 	out.Write("alert indicator", alertIndicatorIndex);
+	out.Write("Show mini-map", minimapDisplayIndex);
+	out.Write("Prioritize flagship use", flagshipSpacePriorityIndex);
 	out.Write("previous saves", previousSaveCount);
+#ifdef _WIN32
+	if(WinVersion::SupportsDarkTheme())
+		out.Write("Title bar theme", titleBarThemeIndex);
+	if(WinVersion::SupportsWindowRounding())
+		out.Write("Window rounding", windowRoundingIndex);
+#endif
 
 	for(const auto &it : settings)
 		out.Write(it.first, it.second);
@@ -418,6 +457,20 @@ void Preferences::SetScrollSpeed(int speed)
 
 
 
+int Preferences::TooltipActivation()
+{
+	return tooltipActivation;
+}
+
+
+
+void Preferences::SetTooltipActivation(int steps)
+{
+	tooltipActivation = steps;
+}
+
+
+
 // View zoom.
 double Preferences::ViewZoom()
 {
@@ -807,3 +860,95 @@ int Preferences::GetPreviousSaveCount()
 {
 	return previousSaveCount;
 }
+
+
+
+void Preferences::ToggleMinimapDisplay()
+{
+	if(++minimapDisplayIndex >= static_cast<int>(MINIMAP_DISPLAY_SETTING.size()))
+		minimapDisplayIndex = 0;
+}
+
+
+
+Preferences::MinimapDisplay Preferences::GetMinimapDisplay()
+{
+	return static_cast<MinimapDisplay>(minimapDisplayIndex);
+}
+
+
+
+const std::string &Preferences::MinimapSetting()
+{
+	return MINIMAP_DISPLAY_SETTING[minimapDisplayIndex];
+}
+
+
+
+void Preferences::ToggleFlagshipSpacePriority()
+{
+	if(++flagshipSpacePriorityIndex >= static_cast<int>(FLAGSHIP_SPACE_PRIORITY_SETTINGS.size()))
+		flagshipSpacePriorityIndex = 0;
+}
+
+
+
+Preferences::FlagshipSpacePriority Preferences::GetFlagshipSpacePriority()
+{
+	return static_cast<FlagshipSpacePriority>(flagshipSpacePriorityIndex);
+}
+
+
+
+const string &Preferences::FlagshipSpacePrioritySetting()
+{
+	return FLAGSHIP_SPACE_PRIORITY_SETTINGS[flagshipSpacePriorityIndex];
+}
+
+
+
+#ifdef _WIN32
+void Preferences::ToggleTitleBarTheme()
+{
+	if(++titleBarThemeIndex >= static_cast<int>(TITLE_BAR_THEME_SETTINGS.size()))
+		titleBarThemeIndex = 0;
+	GameWindow::UpdateTitleBarTheme();
+}
+
+
+
+Preferences::TitleBarTheme Preferences::GetTitleBarTheme()
+{
+	return static_cast<TitleBarTheme>(titleBarThemeIndex);
+}
+
+
+
+const string &Preferences::TitleBarThemeSetting()
+{
+	return TITLE_BAR_THEME_SETTINGS[titleBarThemeIndex];
+}
+
+
+
+void Preferences::ToggleWindowRounding()
+{
+	if(++windowRoundingIndex >= static_cast<int>(WINDOW_ROUNDING_SETTINGS.size()))
+		windowRoundingIndex = 0;
+	GameWindow::UpdateWindowRounding();
+}
+
+
+
+Preferences::WindowRounding Preferences::GetWindowRounding()
+{
+	return static_cast<WindowRounding>(windowRoundingIndex);
+}
+
+
+
+const string &Preferences::WindowRoundingSetting()
+{
+	return WINDOW_ROUNDING_SETTINGS[windowRoundingIndex];
+}
+#endif
