@@ -23,6 +23,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "shader/FillShader.h"
 #include "text/Font.h"
 #include "text/FontSet.h"
+#include "text/Format.h"
 #include "GameData.h"
 #include "Information.h"
 #include "Interface.h"
@@ -41,6 +42,10 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "UI.h"
 #include "text/WrappedText.h"
 
+#ifdef _WIN32
+#include "windows/WinVersion.h"
+#endif
+
 #include "opengl.h"
 
 #include <algorithm>
@@ -73,7 +78,9 @@ namespace {
 	const string FRUGAL_ESCORTS = "Escorts use ammo frugally";
 	const string REACTIVATE_HELP = "Reactivate first-time help";
 	const string SCROLL_SPEED = "Scroll speed";
+	const string TOOLTIP_ACTIVATION = "Tooltip activation time";
 	const string FIGHTER_REPAIR = "Repair fighters in";
+	const string FLAGSHIP_SPACE_PRIORITY = "Prioritize flagship use";
 	const string SHIP_OUTLINES = "Ship outlines in shops";
 	const string DATE_FORMAT = "Date format";
 	const string NOTIFY_ON_DEST = "Notify on destination";
@@ -82,13 +89,16 @@ namespace {
 	const string BACKGROUND_PARALLAX = "Parallax background";
 	const string EXTENDED_JUMP_EFFECTS = "Extended jump effects";
 	const string ALERT_INDICATOR = "Alert indicator";
+	const string MINIMAP_DISPLAY = "Show mini-map";
 	const string HUD_SHIP_OUTLINES = "Ship outlines in HUD";
+#ifdef _WIN32
+	const string TITLE_BAR_THEME = "Title bar theme";
+	const string WINDOW_ROUNDING = "Window rounding";
+#endif
 
 	// How many pages of controls and settings there are.
 	const int CONTROLS_PAGE_COUNT = 2;
 	const int SETTINGS_PAGE_COUNT = 2;
-	// Hovering a preference for this many frames activates the tooltip.
-	const int HOVER_TIME = 60;
 
 	const map<string, SoundCategory> volumeBars = {
 		{"volume", SoundCategory::MASTER},
@@ -109,7 +119,9 @@ namespace {
 
 
 PreferencesPanel::PreferencesPanel(PlayerInfo &player)
-	: player(player), editing(-1), selected(0), hover(-1)
+	: player(player), editing(-1), selected(0), hover(-1),
+	tooltip(270, Alignment::LEFT, Tooltip::Direction::DOWN_LEFT, Tooltip::Corner::TOP_LEFT,
+		GameData::Colors().Get("tooltip background"), GameData::Colors().Get("medium"))
 {
 	// Select the first valid plugin.
 	for(const auto &plugin : Plugins::Get())
@@ -121,11 +133,6 @@ PreferencesPanel::PreferencesPanel(PlayerInfo &player)
 
 	SetIsFullScreen(true);
 
-	// Initialize a centered tooltip.
-	hoverText.SetFont(FontSet::Get(14));
-	hoverText.SetWrapWidth(250);
-	hoverText.SetAlignment(Alignment::LEFT);
-
 	// Set the initial plugin list and description scroll ranges.
 	const Interface *pluginUi = GameData::Interfaces().Get("plugins");
 	Rectangle pluginListBox = pluginUi->GetBox("plugin list");
@@ -214,6 +221,13 @@ void PreferencesPanel::Draw()
 
 
 
+void PreferencesPanel::UpdateTooltipActivation()
+{
+	tooltip.UpdateActivationCount();
+}
+
+
+
 bool PreferencesPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &command, bool isNewPress)
 {
 	if(static_cast<unsigned>(editing) < zones.size())
@@ -237,14 +251,8 @@ bool PreferencesPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &comma
 		hoverItem.clear();
 		selected = 0;
 
-		if(page == 'p')
-		{
-			// Reset the render buffers in case the UI scale has changed.
-			const Interface *pluginUi = GameData::Interfaces().Get("plugins");
-			Rectangle pluginListBox = pluginUi->GetBox("plugin list");
-			pluginListClip = std::make_unique<RenderBuffer>(pluginListBox.Dimensions());
-			RenderPluginDescription(selectedPlugin);
-		}
+		// Reset the render buffers in case the UI scale has changed.
+		Resize();
 	}
 	else if(key == 'o' && page == 'p')
 		Files::OpenUserPluginFolder();
@@ -282,8 +290,10 @@ bool PreferencesPanel::KeyDown(SDL_Keycode key, Uint16 mod, const Command &comma
 
 
 
-bool PreferencesPanel::Click(int x, int y, int clicks)
+bool PreferencesPanel::Click(int x, int y, MouseButton button, int clicks)
 {
+	if(button != MouseButton::LEFT)
+		return false;
 	EndEditing();
 
 	Point point(x, y);
@@ -372,20 +382,32 @@ bool PreferencesPanel::Hover(int x, int y)
 	hoverPoint = Point(x, y);
 
 	hoverItem.clear();
-	tooltip.clear();
+	tooltip.Clear();
 
 	hover = -1;
 	for(unsigned index = 0; index < zones.size(); ++index)
-		if(zones[index].Contains(hoverPoint))
+	{
+		const auto &zone = zones[index];
+		if(zone.Contains(hoverPoint))
+		{
 			hover = index;
+			tooltip.SetZone(zone);
+		}
+	}
 
 	for(const auto &zone : prefZones)
 		if(zone.Contains(hoverPoint))
+		{
 			hoverItem = zone.Value();
+			tooltip.SetZone(zone);
+		}
 
 	for(const auto &zone : pluginZones)
 		if(zone.Contains(hoverPoint))
+		{
 			hoverItem = zone.Value();
+			tooltip.SetZone(zone);
+		}
 
 	return true;
 }
@@ -433,6 +455,17 @@ bool PreferencesPanel::Scroll(double dx, double dy)
 				speed = min(60, speed + 10);
 			Preferences::SetScrollSpeed(speed);
 		}
+		else if(hoverItem == TOOLTIP_ACTIVATION)
+		{
+			int steps = Preferences::TooltipActivation();
+			if(dy < 0.)
+				steps = max(0, steps - 20);
+			else
+				steps = min(120, steps + 20);
+			Preferences::SetTooltipActivation(steps);
+			for(auto &panel : GetUI()->Stack())
+				panel->UpdateTooltipActivation();
+		}
 		return true;
 	}
 	else if(page == 'p')
@@ -483,6 +516,19 @@ bool PreferencesPanel::Drag(double dx, double dy)
 
 
 
+void PreferencesPanel::Resize()
+{
+	if(page == 'p')
+	{
+		const Interface *pluginUi = GameData::Interfaces().Get("plugins");
+		Rectangle pluginListBox = pluginUi->GetBox("plugin list");
+		pluginListClip = std::make_unique<RenderBuffer>(pluginListBox.Dimensions());
+		RenderPluginDescription(selectedPlugin);
+	}
+}
+
+
+
 void PreferencesPanel::EndEditing()
 {
 	editing = -1;
@@ -550,8 +596,9 @@ void PreferencesPanel::DrawControls()
 		Command::NONE,
 		Command::DEPLOY,
 		Command::FIGHT,
+		Command::HOLD_FIRE,
 		Command::GATHER,
-		Command::HOLD,
+		Command::HOLD_POSITION,
 		Command::AMMO,
 		Command::HARVEST,
 		Command::NONE,
@@ -737,7 +784,7 @@ void PreferencesPanel::DrawSettings()
 		"Highlight player's flagship",
 		"Rotate flagship in HUD",
 		"Show planet labels",
-		"Show mini-map",
+		MINIMAP_DISPLAY,
 		"Clickable radar display",
 		ALERT_INDICATOR,
 		"Extra fleet status messages",
@@ -756,23 +803,31 @@ void PreferencesPanel::DrawSettings()
 		"Fighters transfer cargo",
 		"Rehire extra crew when lost",
 		"Automatically unpark flagship",
-		"",
+		FLAGSHIP_SPACE_PRIORITY,
+		"\t",
 		"Map",
 		"Deadline blink by distance",
 		"Hide unexplored map regions",
 		"Show escort systems on map",
 		"Show stored outfits on map",
 		"System map sends move orders",
-		"\t",
+		"",
 		"Other",
 		"Always underline shortcuts",
 		REACTIVATE_HELP,
 		"Interrupt fast-forward",
 		"Landing zoom",
 		SCROLL_SPEED,
+		TOOLTIP_ACTIVATION,
 		DATE_FORMAT,
 		"Show parenthesis",
 		NOTIFY_ON_DEST
+#ifdef _WIN32
+		, "",
+		"Windows Options",
+		TITLE_BAR_THEME,
+		WINDOW_ROUNDING
+#endif
 	};
 
 	bool isCategory = true;
@@ -920,6 +975,11 @@ void PreferencesPanel::DrawSettings()
 			isOn = true;
 			text = Preferences::Has(FIGHTER_REPAIR) ? "parallel" : "series";
 		}
+		else if(setting == FLAGSHIP_SPACE_PRIORITY)
+		{
+			isOn = Preferences::GetFlagshipSpacePriority() != Preferences::FlagshipSpacePriority::NONE;
+			text = Preferences::FlagshipSpacePrioritySetting();
+		}
 		else if(setting == SHIP_OUTLINES)
 		{
 			isOn = true;
@@ -986,11 +1046,33 @@ void PreferencesPanel::DrawSettings()
 			isOn = true;
 			text = to_string(Preferences::ScrollSpeed());
 		}
+		else if(setting == TOOLTIP_ACTIVATION)
+		{
+			isOn = true;
+			text = Format::StepsToSeconds(Preferences::TooltipActivation());
+		}
 		else if(setting == ALERT_INDICATOR)
 		{
 			isOn = Preferences::GetAlertIndicator() != Preferences::AlertIndicator::NONE;
 			text = Preferences::AlertSetting();
 		}
+		else if(setting == MINIMAP_DISPLAY)
+		{
+			isOn = Preferences::GetMinimapDisplay() != Preferences::MinimapDisplay::OFF;
+			text = Preferences::MinimapSetting();
+		}
+#ifdef _WIN32
+		else if(setting == TITLE_BAR_THEME)
+		{
+			isOn = WinVersion::SupportsDarkTheme();
+			text = isOn ? Preferences::TitleBarThemeSetting() : "N/A";
+		}
+		else if(setting == WINDOW_ROUNDING)
+		{
+			isOn = WinVersion::SupportsWindowRounding();
+			text = isOn ? Preferences::WindowRoundingSetting() : "N/A";
+		}
+#endif
 		else
 			text = isOn ? "on" : "off";
 
@@ -1203,38 +1285,17 @@ void PreferencesPanel::DrawTooltips()
 {
 	if(hoverItem.empty())
 	{
-		// Step the tooltip timer back.
-		hoverCount -= hoverCount ? 1 : 0;
+		tooltip.DecrementCount();
 		return;
 	}
-
-	// Step the tooltip timer forward [0-60].
-	hoverCount += hoverCount < HOVER_TIME;
-
-	if(hoverCount < HOVER_TIME)
+	tooltip.IncrementCount();
+	if(!tooltip.ShouldDraw())
 		return;
 
-	// Create the tooltip text.
-	if(tooltip.empty())
-	{
-		tooltip = GameData::Tooltip(hoverItem);
-		// No tooltip for this item.
-		if(tooltip.empty())
-			return;
-		hoverText.Wrap(tooltip);
-	}
+	if(!tooltip.HasText())
+		tooltip.SetText(GameData::Tooltip(hoverItem));
 
-	Point size(hoverText.WrapWidth(), hoverText.Height() - hoverText.ParagraphBreak());
-	size += Point(20., 20.);
-	Point topLeft = hoverPoint;
-	// Do not overflow the screen dimensions.
-	if(topLeft.X() + size.X() > Screen::Right())
-		topLeft.X() -= size.X();
-	if(topLeft.Y() + size.Y() > Screen::Bottom())
-		topLeft.Y() -= size.Y();
-	// Draw the background fill and the tooltip text.
-	FillShader::Fill(topLeft + .5 * size, size, *GameData::Colors().Get("tooltip background"));
-	hoverText.Draw(topLeft + Point(10., 10.), *GameData::Colors().Get("medium"));
+	tooltip.Draw();
 }
 
 
@@ -1338,12 +1399,31 @@ void PreferencesPanel::HandleSettingsString(const string &str, Point cursorPosit
 			speed = 10;
 		Preferences::SetScrollSpeed(speed);
 	}
+	else if(str == TOOLTIP_ACTIVATION)
+	{
+		int steps = Preferences::TooltipActivation() + 20;
+		if(steps > 120)
+			steps = 0;
+		Preferences::SetTooltipActivation(steps);
+		for(auto &panel : GetUI()->Stack())
+			panel->UpdateTooltipActivation();
+	}
+	else if(str == FLAGSHIP_SPACE_PRIORITY)
+		Preferences::ToggleFlagshipSpacePriority();
 	else if(str == DATE_FORMAT)
 		Preferences::ToggleDateFormat();
 	else if(str == NOTIFY_ON_DEST)
 		Preferences::ToggleNotificationSetting();
 	else if(str == ALERT_INDICATOR)
 		Preferences::ToggleAlert();
+	else if(str == MINIMAP_DISPLAY)
+		Preferences::ToggleMinimapDisplay();
+#ifdef _WIN32
+	else if(str == TITLE_BAR_THEME)
+		Preferences::ToggleTitleBarTheme();
+	else if(str == WINDOW_ROUNDING)
+		Preferences::ToggleWindowRounding();
+#endif
 	// All other options are handled by just toggling the boolean state.
 	else
 		Preferences::Set(str, !Preferences::Has(str));
