@@ -21,7 +21,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "Command.h"
 #include "Point.h"
 #include "ScrollVar.h"
-#include "text/WrappedText.h"
+#include "Tooltip.h"
 
 #include <memory>
 #include <string>
@@ -42,15 +42,19 @@ public:
 	// Draw this panel.
 	virtual void Draw() override;
 
+	virtual void UpdateTooltipActivation() override;
+
 
 protected:
 	// Only override the ones you need; the default action is to return false.
 	virtual bool KeyDown(SDL_Keycode key, Uint16 mod, const Command &command, bool isNewPress) override;
-	virtual bool Click(int x, int y, int clicks) override;
+	virtual bool Click(int x, int y, MouseButton button, int clicks) override;
 	virtual bool Hover(int x, int y) override;
 	virtual bool Scroll(double dx, double dy) override;
 	virtual bool Drag(double dx, double dy) override;
 
+	virtual void Resize() override;
+
 	virtual void EndEditing() override;
 
 
@@ -91,11 +95,9 @@ private:
 	char page = 'c';
 
 	Point hoverPoint;
-	int hoverCount = 0;
+	Tooltip tooltip;
 	std::string selectedItem;
 	std::string hoverItem;
-	std::string tooltip;
-	WrappedText hoverText;
 
 	int currentControlsPage = 0;
 	int currentSettingsPage = 0;
