@@ -13,13 +13,12 @@ You should have received a copy of the GNU General Public License along with
 this program. If not, see <https://www.gnu.org/licenses/>.
 */
 
-#ifndef RAID_FLEET_H_
-#define RAID_FLEET_H_
+#pragma once
 
 #include <vector>
 
-class Fleet;
 class DataNode;
+class Fleet;
 
 
 
@@ -39,7 +38,3 @@ private:
 	double minAttraction;
 	double maxAttraction;
 };
-
-
-
-#endif
