@@ -23,12 +23,10 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 // Class that can redirect all drawing commands to an internal texture.
 // This buffer uses coordinates from (0, 0) in the top left, to (width, height)
 // in the bottom right.
-class RenderBuffer
-{
+class RenderBuffer {
 public:
 	// RAII wrapper to prevent accidentally not unbinding the render target.
-	class RenderTargetGuard final
-	{
+	class RenderTargetGuard final {
 	public:
 		~RenderTargetGuard();
 
