@@ -135,7 +135,7 @@ void ShipInfoDisplay::DrawOutfits(const Point &topLeft) const
 void ShipInfoDisplay::UpdateAttributes(const Ship &ship, const PlayerInfo &player, bool descriptionCollapsed,
 		bool scrollingPanel)
 {
-	bool isGeneric = ship.Name().empty() || ship.GetPlanet();
+	bool isGeneric = ship.GivenName().empty() || ship.GetPlanet();
 
 	attributeHeaderLabels.clear();
 	attributeHeaderValues.clear();
