@@ -540,14 +540,10 @@ void System::UpdateSystem(const Set<System> &systems, const set<double> &neighbo
 		for(const double distance : neighborDistances)
 			UpdateNeighbors(systems, distance);
 
-	// Calculate the solar power and solar wind.
-	solarPower = 0.;
-	solarWind = 0.;
+	// Cache the map star icons.
 	mapIcons.clear();
 	for(const StellarObject &object : objects)
 	{
-		solarPower += GameData::SolarPower(object.GetSprite());
-		solarWind += GameData::SolarWind(object.GetSprite());
 		const Sprite *starIcon = GameData::StarIcon(object.GetSprite());
 		if(starIcon)
 			mapIcons.emplace_back(starIcon);
@@ -604,7 +600,7 @@ const string &System::TrueName() const
 
 
 
-void System::SetName(const string &name)
+void System::SetTrueName(const string &name)
 {
 	trueName = name;
 	if(displayName.empty())
@@ -708,14 +704,27 @@ bool System::Inaccessible() const
 
 
 
-// Return how much ramscoop is generated by this system, depending on the given ship ramscoop value.
-double System::RamscoopFuel(double shipRamscoop, double scale) const
+// Return how much ramscoop fuel and solar energy/heat is generated by this system
+// for a ship with the attributes and position.
+System::SolarGeneration System::GetSolarGeneration(const Point &shipPosition,
+	double shipRamscoop, double shipCollection, double shipCollectionHeat) const
 {
-	// Even if a ship has no ramscoop, it can harvest a tiny bit of fuel by flying close to the star,
-	// provided the system allows it. Both the system and the gamerule must allow the universal ramscoop
-	// in order for it to function.
-	double universal = 0.05 * scale * universalRamscoop * GameData::GetGamerules().UniversalRamscoopActive();
-	return max(0., SolarWind() * .03 * scale * ramscoopMultiplier * (sqrt(shipRamscoop) + universal) + ramscoopAddend);
+	SolarGeneration generation{ramscoopAddend, 0., 0.};
+	for(const auto &stellar : objects)
+	{
+		double power = GameData::SolarPower(stellar.GetSprite());
+		double wind = GameData::SolarWind(stellar.GetSprite());
+		double scale = .2 + 1.8 / (.001 * stellar.position.Distance(shipPosition) + 1);
+		// Even if a ship has no ramscoop, it can harvest a tiny bit of fuel by flying close to the star,
+		// provided the system allows it. Both the system and the gamerule must allow the universal ramscoop
+		// in order for it to function.
+		double universal = .05 * scale * universalRamscoop * GameData::GetGamerules().UniversalRamscoopActive();
+		generation.fuel += wind * .03 * scale * ramscoopMultiplier * (sqrt(shipRamscoop) + universal);
+		generation.energy += power * shipCollection * scale;
+		generation.heat += power * shipCollectionHeat * scale;
+	}
+	generation.fuel = max(0., generation.fuel);
+	return generation;
 }
 
 
@@ -723,7 +732,10 @@ double System::RamscoopFuel(double shipRamscoop, double scale) const
 // Additional travel distance to target for ships entering through hyperspace.
 double System::ExtraHyperArrivalDistance() const
 {
-	return max(extraHyperArrivalDistance, GameData::GetGamerules().SystemArrivalMin());
+	const optional<double> arrivalGamerule = GameData::GetGamerules().SystemArrivalMin();
+	if(arrivalGamerule.has_value())
+		return max(extraHyperArrivalDistance, *arrivalGamerule);
+	return extraHyperArrivalDistance;
 }
 
 
@@ -731,7 +743,10 @@ double System::ExtraHyperArrivalDistance() const
 // Additional travel distance to target for ships entering using a jumpdrive.
 double System::ExtraJumpArrivalDistance() const
 {
-	return max(extraJumpArrivalDistance, GameData::GetGamerules().SystemArrivalMin());
+	const optional<double> arrivalGamerule = GameData::GetGamerules().SystemArrivalMin();
+	if(arrivalGamerule.has_value())
+		return max(extraJumpArrivalDistance, *arrivalGamerule);
+	return extraJumpArrivalDistance;
 }
 
 
@@ -849,21 +864,6 @@ double System::JumpRange() const
 
 
 
-// Get the rate of solar collection and ramscoop refueling.
-double System::SolarPower() const
-{
-	return solarPower;
-}
-
-
-
-double System::SolarWind() const
-{
-	return solarWind;
-}
-
-
-
 double System::StarfieldDensity() const
 {
 	return starfieldDensity;
