@@ -66,6 +66,12 @@ public:
 		double energy;
 	};
 
+	struct SolarGeneration {
+		double fuel;
+		double energy;
+		double heat;
+	};
+
 
 public:
 	// Load a system's description.
@@ -80,7 +86,7 @@ public:
 
 	bool IsValid() const;
 	const std::string &TrueName() const;
-	void SetName(const std::string &name);
+	void SetTrueName(const std::string &name);
 	// Get this system's name and position (in the star map).
 	const std::string &DisplayName() const;
 	const Point &Position() const;
@@ -108,9 +114,10 @@ public:
 	bool Shrouded() const;
 	// Defines whether this system can be accessed or interacted with in any way.
 	bool Inaccessible() const;
-	// Return how much ramscoop fuel is generated by this system,
-	// depending on the given ship ramscoop value and the given scale.
-	double RamscoopFuel(double shipRamscoop, double scale) const;
+	// Return how much ramscoop fuel and solar energy/heat is generated by this system
+	// for a ship with the attributes and position.
+	SolarGeneration GetSolarGeneration(const Point &shipPosition,
+		double shipRamscoop, double shipCollection, double shipCollectionHeat) const;
 	// Additional travel distance to target for ships entering through hyperspace.
 	double ExtraHyperArrivalDistance() const;
 	// Additional travel distance to target for ships entering using a jumpdrive.
@@ -141,9 +148,6 @@ public:
 	double InvisibleFenceRadius() const;
 	// Get how far ships can jump from this system.
 	double JumpRange() const;
-	// Get the rate of solar collection and ramscoop refueling.
-	double SolarPower() const;
-	double SolarWind() const;
 	// Get the starfield density for this system.
 	double StarfieldDensity() const;
 	// Check if this system is inhabited.
@@ -255,8 +259,6 @@ private:
 	WeightedList<double> belts;
 	double invisibleFenceRadius = 10000.;
 	double jumpRange = 0.;
-	double solarPower = 0.;
-	double solarWind = 0.;
 	double starfieldDensity = 1.;
 	int minimumFleetPeriod = 0;
 
