@@ -15,9 +15,9 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 
 #pragma once
 
-#include "CategoryTypes.h"
-#include "Sale.h"
+#include "CategoryType.h"
 #include "Set.h"
+#include "Shop.h"
 
 #include "CategoryList.h"
 #include "Color.h"
@@ -38,8 +38,10 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include "Person.h"
 #include "Phrase.h"
 #include "Planet.h"
+#include "shader/Shader.h"
 #include "Ship.h"
 #include "StartConditions.h"
+#include "Swizzle.h"
 #include "System.h"
 #include "test/Test.h"
 #include "test/TestData.h"
@@ -56,8 +58,9 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 #include <string>
 #include <vector>
 
-
+class ConditionsStore;
 class Panel;
+class PlayerInfo;
 class Sprite;
 class TaskQueue;
 
@@ -72,14 +75,14 @@ class UniverseObjects {
 public:
 	// Load game objects from the given directories of definitions.
 	std::shared_future<void> Load(TaskQueue &queue, const std::vector<std::filesystem::path> &sources,
-		bool debugMode = false);
+		const PlayerInfo &player, const ConditionsStore *globalConditions, bool debugMode = false);
 	// Determine the fraction of data files read from disk.
 	double GetProgress() const;
 	// Resolve every game object dependency.
 	void FinishLoading();
 
 	// Apply the given change to the universe.
-	void Change(const DataNode &node);
+	void Change(const DataNode &node, const PlayerInfo &player);
 	// Update the neighbor lists and other information for all the systems.
 	// (This must be done any time a GameEvent creates or moves a system.)
 	void UpdateSystems();
@@ -93,7 +96,8 @@ public:
 
 
 private:
-	void LoadFile(const std::filesystem::path &path, bool debugMode = false);
+	void LoadFile(const std::filesystem::path &path, const PlayerInfo &player,
+		const ConditionsStore *globalConditions, bool debugMode = false);
 
 
 private:
@@ -103,6 +107,7 @@ private:
 
 private:
 	Set<Color> colors;
+	Set<Swizzle> swizzles;
 	Set<Conversation> conversations;
 	Set<Effect> effects;
 	Set<GameEvent> events;
@@ -119,12 +124,13 @@ private:
 	Set<Person> persons;
 	Set<Phrase> phrases;
 	Set<Planet> planets;
+	Set<Shader> shaders;
 	Set<Ship> ships;
 	Set<System> systems;
 	Set<Test> tests;
 	Set<TestData> testDataSets;
-	Set<Sale<Ship>> shipSales;
-	Set<Sale<Outfit>> outfitSales;
+	Set<Shop<Ship>> shipSales;
+	Set<Shop<Outfit>> outfitSales;
 	Set<Wormhole> wormholes;
 	std::set<double> neighborDistances;
 
