@@ -72,6 +72,41 @@ void Weapon::LoadWeapon(const DataNode &node)
 			canCollideAsteroids = false;
 		else if(key == "no minable collisions")
 			canCollideMinables = false;
+		else if(key == "homing")
+		{
+			homing = true;
+			// Convert the old formatting for defining homing for reverse
+			// compatibility.
+			if(child.Size() == 2)
+			{
+				child.PrintTrace("Warning: Deprecated use of \"homing\" followed by a value."
+					" Define individual homing attributes instead:");
+				int value = child.Value(1);
+				if(value >= 3)
+				{
+					throttleControl = true;
+					if(value >= 4)
+						leading = true;
+				}
+				else if(value == 1)
+					blindspot = true;
+				else if(value == 0)
+					homing = false;
+			}
+			for(const DataNode &grand : child)
+			{
+				const string &grandKey = grand.Token(0);
+
+				if(grandKey == "blindspot")
+					blindspot = true;
+				else if(grandKey == "throttle control")
+					throttleControl = true;
+				else if(grandKey == "leading")
+					leading = true;
+				else
+					grand.PrintTrace("Skipping unknown homing attribute:");
+			}
+		}
 		else if(child.Size() < 2)
 			child.PrintTrace("Skipping weapon attribute with no value specified:");
 		else if(key == "sprite")
@@ -183,8 +218,6 @@ void Weapon::LoadWeapon(const DataNode &node)
 				burstReload = max(1., value);
 			else if(key == "burst count")
 				burstCount = max(1., value);
-			else if(key == "homing")
-				homing = value;
 			else if(key == "missile strength")
 				missileStrength = max(0., value);
 			else if(key == "anti-missile")
