@@ -17,7 +17,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 
 #include "../Color.h"
 #include "../GameData.h"
-#include "../Point.h"
+#include "../Rectangle.h"
 #include "../Screen.h"
 #include "Shader.h"
 
@@ -71,6 +71,13 @@ void FillShader::Init()
 
 
 
+void FillShader::Fill(const Rectangle &area, const Color &color)
+{
+	Fill(area.Center(), area.Dimensions(), color);
+}
+
+
+
 void FillShader::Fill(const Point &center, const Point &size, const Color &color)
 {
 	if(!shader || !shader->Object())
