@@ -15,7 +15,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 
 #pragma once
 
-#include "layout.hpp"
+#include "Layout.h"
 
 #include <string>
 
