@@ -15,7 +15,7 @@ this program. If not, see <https://www.gnu.org/licenses/>.
 
 #pragma once
 
-#include <string>
+#include <filesystem>
 
 class Font;
 
@@ -25,6 +25,6 @@ class Font;
 // based on a glyph image; right now only point sizes 14 and 18 exist.
 class FontSet {
 public:
-	static void Add(const std::string &path, int size);
+	static void Add(const std::filesystem::path &path, int size);
 	static const Font &Get(int size);
 };
