@@ -49,6 +49,16 @@ SCENARIO( "Creating an Account" , "[Account][Creation]" ) {
 				REQUIRE( account.TotalDebt() == 10000 );
 			}
 		}
+		WHEN( "Mortgage is added" ) {
+			REQUIRE(account.Credits() == 0);
+			account.AddMortgage(200);
+			THEN( "The credits increased and the mortgage was added" ) {
+				REQUIRE( account.Credits() == 200);
+				REQUIRE( account.Mortgages().back().Type() == "Mortgage" );
+				REQUIRE( account.Mortgages().back().Principal() == 200);
+				REQUIRE( account.Mortgages().back().Interest() == ("0." + std::to_string(600 - account.CreditScore() / 2) + "%"));
+			}
+		}
 	}
 }
 // #endregion unit tests
